@@ -1,7 +1,6 @@
 
-#if defined __INTEL_COMPILER
-#define _BSD_SOURCE 1
-#define _POSIX_C_SOURCE  200809L
+#ifndef _GNU_SOURCE
+#define _GNU_SOURCE 1
 #endif
 
 #include <unistd.h>
